#
# spec file for package perl-Statistics-Descriptive
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Statistics-Descriptive
Version:        3.0612
Release:        2.5
%define cpan_name Statistics-Descriptive
Summary:        Module of basic descriptive statistical functions
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Statistics-Descriptive/
Source0:        http://www.cpan.org/authors/id/S/SH/SHLOMIF/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(List::MoreUtils)
BuildRequires:  perl(Module::Build) >= 0.360000
Requires:       perl(List::MoreUtils)
%{perl_requires}

%description
This module provides basic functions used in descriptive statistics. It has
an object oriented design and supports two different types of data storage
and calculation objects: sparse and full. With the sparse method, none of
the data is stored and only a few statistical measures are available. Using
the full method, the entire data set is retained and additional functions
are available.

Whenever a division by zero may occur, the denominator is checked to be
greater than the value '$Statistics::Descriptive::Tolerance', which
defaults to 0.0. You may want to change this value to some small positive
value such as 1e-24 in order to obtain error messages in case of very small
denominators.

Many of the methods (both Sparse and Full) cache values so that subsequent
calls with the same arguments are faster.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes examples LICENSE README rejects scripts UserSurvey.txt

%changelog
* Wed Jan 13 2016 coolo@suse.com
- updated to 3.0612
  see /usr/share/doc/packages/perl-Statistics-Descriptive/Changes
  3.0612      2016-01-09
  - Move the VCS repository to GitHub.
  - People are more used to it, and it can take part in the CPAN pull-req
    challenge.
  3.0611      2016-01-07
  - Apply patch from Debian to correct a spelling error.
  - https://rt.cpan.org/Ticket/Display.html?id=110987
  - Thanks to Salvatore Bonaccorso for the report and patch.
  3.0610      2016-01-06
  - Clarified the docs for add_data_with_samples().
  - Some people thought they were repeat counts of the data , but they
    are normally ignored.
  - Replace remaining tabs with spaces.
* Sun Jun 21 2015 coolo@suse.com
- updated to 3.0609
  see /usr/share/doc/packages/perl-Statistics-Descriptive/Changes
  3.0609      2015-06-19
  - Update some old URLs and addresses.
* Fri Mar 27 2015 stephan.barth@suse.com
- Fixed broken link.
* Sat Feb  7 2015 coolo@suse.com
- updated to 3.0608
  - Apply patch to speed up skewness calculations.
  - https://rt.cpan.org/Public/Bug/Display.html?id=101422
  - Thanks to Shawn (SLAFFAN).
* Sun Feb  9 2014 coolo@suse.com
- updated to 3.0607
  - Fix the List::MoreUtils prereqs.
  - http://www.cpantesters.org/cpan/report/365b752c-8adf-11e3-bd14-e3bee4621ba3
  - Thanks to Chris Williams (BINGOS) for the CPAN Testers Report.
  - Implement the median_absolute_deviation method.
  - https://bitbucket.org/shlomif/perl-statistics-descriptive/pull-request/5/median-absolute-deviation-method/diff
  - Thanks to Kang-min Liu.
  - Minimal version of perl set to 5.6.0 (CPANTS).
  - Add standalone LICENSE file (CPANTS).
* Tue Jun  4 2013 coolo@suse.com
- updated to 3.0605
  - Add t/style-trailing-space.t .
  - Add t/cpan-changes.t .
  - Convert Changes to it.
  - Correct a misspelling of "weight" in
    lib/Statistics/Descriptive/Smoother/Weightedexponential.pm
  - Thanks to Wilhelm for the report.
  - Update the scripts/tag-release.pl file for Mercurial.
  - Use in_between to compare decimal numbers
  - Smoothing tests were failing because of rounding problems
  - Thanks to Andreas J. König for reporting it and to
    Fabio Ponciroli for fixing it.
  - Correct a typo:
  - https://rt.cpan.org/Ticket/Display.html?id=77145
  - Thanks to Salvatore Bonaccorso and the Debian Perl Group
    for the report.
  - No longer using Test::Exception in the tests.
  - It was used by the tests and not specified in
    test_requires/build_requires.
  - Thanks to hsk@fli-leibniz.de for the report.
  - Add the smoothing functionality.
  - Add the following public methods: add_data_with_samples(),
    set_smoother(), get_smoothed_data() to the main module.
  - Add the lib/Statistics/Descriptive/Smoother.pm and
    lib/Statistics/Descriptive/Smoother/Exponential.pm
    lib/Statistics/Descriptive/Smoother/Weightedexponential.pm
    modules.
  - Thanks to Fabio Ponciroli
  - Add the scripts/bump-version-number.pl to facilitate bumping the
    version number.
  - Add the get_data_without_outliers() and the set_outlier_filter()
    methods.
  - See https://bitbucket.org/barbasa/perl-statistics-descriptive/overview
  - Thanks to Fabio Ponciroli
* Fri Feb 17 2012 coolo@suse.com
- updated to 3.0300
  - Now mean() and median() and other routines return undef() if there are
  no data.
  - Somewhat incompatible change: some methods that returned undef() under
  list context now return an empty list (so it will be false).
  - it is generally not recommended to call such methods in list context
    as they should always be called in scalar context.
  - Resolves https://rt.cpan.org/Ticket/Display.html?id=74693
  - thanks to Shawn Laffan for the report and the patch.
  - Fix https://rt.cpan.org/Ticket/Display.html?id=72495 .
  - percentile should not die and should return undef if there are
    no elements in the collection.
* Mon Dec 19 2011 coolo@suse.de
- update to 3.0202
  - Moved tag-release.pl to scripts/tag-release.pl (though we now use
    Mercurial instead of Subversion.)
  - Add t/mode.t to test the ->mode() method.
  - Documented ->mode() better.
  - Optimized ->mode().
  - Add some documentation clarifying the 0th percentile return, as it
    returns undef() for representing -inf:
  - Fix https://rt.cpan.org/Ticket/Display.html?id=62055
  - Thanks to Dave Breimann for reporting it.
  - Add the tag-release.pl to tag a release using Subversion.
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Aug  4 2010 chris@computersalat.de
- initial package 3.0200
  * created by cpanspec 1.78
